##  Customizing Relations
In SAP LeanIX, the customer owns the meta model. Depending on your needs, you have the option to choose a different relation between the microservice subtype and the teams or business application subtypes.
![Configuring Relations Between Microservice to Team and Business Application Fact Sheet Types](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754ea9b7a441014b1508ed8ffd5c5aa_LowRes.png)
Configuring Relations Between Microservice to Team and Business Application Fact Sheet Types
Incoming manifests use the configured relations to link microservices to the relevant team and business application subtypes when the manifest includes references to teams or applications. To learn more, see [Manifest File and Schema](https://help.sap.com/docs/leanix/ea/manifest-file-and-schema?locale=en-US&state=PRODUCTION&version=CLOUD "Manifest file for microservice discovery and the manifest schema."). Also, the SBOM explorer uses these relations to fetch and show the associated teams and business applications.
To adjust relation settings, click Edit next to Provisioned Relations, select the custom relations from the relevant drop-down lists for the teams and business application subtypes, then save the changes.
![Configuring Relations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748d1447a441014a8eba05ad1cd0ec7_LowRes.png)
Configuring Relations
